Package: tm
Title: Text Mining Package
Version: 0.7-18
Date: 2026-02-18
Authors@R: c(person("Ingo", "Feinerer", role = "aut",
                    email = "feinerer@logic.at",
                    comment = c(ORCID = "0000-0001-7656-8338")),
             person("Kurt", "Hornik", role = c("aut", "cre"),
     		    email = "Kurt.Hornik@R-project.org",
                    comment = c(ORCID = "0000-0003-4198-9911")),
             person("Artifex Software, Inc.", role = c("ctb", "cph"),
                    comment = "pdf_info.ps taken from GPL Ghostscript"))
Depends: R (>= 3.4.0), NLP (>= 0.2-0)
Imports: Rcpp, parallel, slam (>= 0.1-37), stats, tools, utils,
        graphics, xml2
LinkingTo: BH, Rcpp
Suggests: antiword, filehash, methods, pdftools, Rcampdf, Rgraphviz,
        Rpoppler, SnowballC, testthat, tm.lexicon.GeneralInquirer
Description: A framework for text mining applications within R.
License: GPL-3
URL: https://tm.r-forge.r-project.org/
Additional_repositories: https://datacube.wu.ac.at
NeedsCompilation: yes
Packaged: 2026-02-18 10:06:28 UTC; hornik
Author: Ingo Feinerer [aut] (ORCID: <https://orcid.org/0000-0001-7656-8338>),
  Kurt Hornik [aut, cre] (ORCID: <https://orcid.org/0000-0003-4198-9911>),
  Artifex Software, Inc. [ctb, cph] (pdf_info.ps taken from GPL
    Ghostscript)
Maintainer: Kurt Hornik <Kurt.Hornik@R-project.org>
Repository: CRAN
Date/Publication: 2026-02-18 11:15:00 UTC
