bibentry(bibtype = "InProceedings",
         key = "Feinerer:2010",
         author = person(given = "Ingo",
                         family = "Feinerer"),
         editor = c(person(given = "Pu-Jen",
                           family = "Cheng"),
                    person(given = "Min-Yen",
                           family = "Kan"),
                    person(given = "Wai",
                           family = "Lam"),
                    person(given = "Preslav",
                           family = "Nakov")),
         title = "Analysis and Algorithms for Stemming Inversion",
         booktitle = "Information Retrieval Technology",
         year = "2010",
         publisher = "Springer Berlin Heidelberg",
         address = "Berlin, Heidelberg",
         pages = "290--299",
         isbn = "978-3-642-17187-1",
         doi = "10.1007/978-3-642-17187-1_28")

bibentry(bibtype = "Misc",
         key = "Lewis:1987",
         doi = "10.24432/C52G6M",
         author = person(given = "David",
                         family = "Lewis"),
         title = "Reuters-21578 Text Categorization Collection",
         publisher = "UCI Machine Learning Repository",
         year = "1987")

bibentry(bibtype = "Article",
         key = "Lewis+Yang+Rose:2004",
         author = c(person(given = c("David", "D."),
                           family = "Lewis"),
                    person(given = "Yiming",
                           family = "Yang"),
                    person(given = c("Tony", "G."),
                           family = "Rose"),
                    person(given = "Fan",
                           family = "Li")),
         title = "{RCV1}: A New Benchmark Collection for Text Categorization Research",
         journal = "Journal of Machine Learning Research",
         year = "2004",
         volume = "5",
         pages = "361--397",
         url = "https://www.jmlr.org/papers/volume5/lewis04a/lewis04a.pdf")

bibentry(bibtype = "Book",
         key = "Manning+Raghavan+Schütze:2008",
         author = c(person(given = c("Christopher", "D."),
                           family = "Manning"),
                    person(given = "Prabhakar",
                           family = "Raghavan"),
                    person(given = "Hinrich",
                           family = "Schütze")),
         title = "Introduction to Information Retrieval",
         publisher = "Cambridge University Press",
         year = "2008",
         doi = "10.1017/CBO9780511809071")

bibentry(bibtype = "Article",
         key = "Salton+Buckley:1988",
         author = c(person(given = "Gerard",
                           family = "Salton"),
                    person(given = "Christopher",
                           family = "Buckley")),
         title = "Term-weighting Approaches in Automatic Text Retrieval",
         journal = "Information Processing and Management",
         year = "1988",
         volume = "24",
         number = "5",
         pages = "513--523",
         doi = "10.1016/0306-4573(88)90021-0")
