# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

tdm <- function(strings, remove_puncts, remove_digits, stopwords, dictionary, min_term_freq, max_term_freq, min_word_length, max_word_length) {
    .Call(`_tm_tdm`, strings, remove_puncts, remove_digits, stopwords, dictionary, min_term_freq, max_term_freq, min_word_length, max_word_length)
}

Boost_Tokenizer <- function(strings) {
    .Call(`_tm_Boost_Tokenizer`, strings)
}

